@@ -9,18 +9,41 @@ log_format = logging.Formatter(
     "[%(asctime)s] %(filename)s/%(lineno)s/%(funcName)s/%(levelname)s: %(message)s"
 )
 
-console_handler = logging.StreamHandler(stream=sys.stdout)
-console_handler.setFormatter(log_format)
-console_handler.setLevel(logging.INFO)
-
+# 日志句柄
 logger = logging.getLogger("DengUtils")
-logger.addHandler(console_handler)
-logger.setLevel(logging.INFO)
+# 此处必须为DEBUG，否则在UiBot中多次加载时会覆盖configure_logger中level配置
+logger.setLevel(logging.DEBUG)
+
+# 防止多次加载时产生重复的StreamHandler handler
+if len(logger.handlers) == 0:
+    console_handler = logging.StreamHandler(stream=sys.stdout)
+    console_handler.setFormatter(log_format)
+    console_handler.setLevel(logging.INFO)
+    logger.addHandler(console_handler)
 
 
 def clean_handler():
-    for handler in logger.handlers:
-        logger.removeHandler(handler)
+    """清理日志handler，关闭所有FileHandler实例，StreamHandler实例只保留一个"""
+    _first_console = False
+    logger.debug(f"开始清理日志句柄：{logger.handlers}")
+    for _handler in logger.handlers:
+        if isinstance(_handler, logging.FileHandler):
+            logger.debug(f"关闭：{_handler}")
+            _handler.flush()
+            _handler.close()
+            logger.removeHandler(_handler)
+        elif isinstance(_handler, logging.StreamHandler):
+            # 对于StreamHandler实例，仅保留一个，防止越积越多
+            if _first_console is False:
+                _first_console = True
+                logger.debug(f"保留：{_handler}")
+            else:
+                logger.debug(f"关闭：{_handler}")
+                _handler.flush()
+                _handler.close()
+                logger.removeHandler(_handler)
+        else:
+            logger.debug(f"忽略：{_handler}")
 
 
 def configure_logger(
