@@ -173,6 +173,7 @@ def pull_repo(
     lfs: bool = False,
     pattern: str = None,
     no_exist_create_modle: str = None,
+    consistency_check: bool = True,
 ):
     """拉取代码"""
     start_time = time.perf_counter()
@@ -220,6 +221,22 @@ def pull_repo(
                     utils.execute_cmd(["git", "push", "-u", remote, branch])
                 else:
                     raise ValueError(f"库{repo_name}远程分支不存在：{branch}")
+
+        # 检查本地分支与远程分支是否一致
+        res = utils.execute_cmd(["git", "status"], level="debug")
+        # 工作目录干净，不需要处理
+        if (
+                f"Your branch is up to date with '{remote}/{branch}'." in res.stdout
+                or f"您的分支与上游分支 '{remote}/{branch}' 一致。" in res.stdout
+        ):
+            logger.debug(f"仓库{repo_path}分支{branch}与上游{remote}/{branch}分支一致")
+        else:
+            output_str = utils.bytes_to_str(res.stdout)
+            logger.warning(output_str)
+            if consistency_check:
+                raise ValueError("分支不一致\n" + output_str)
+            else:
+                logger.warning(f"仓库{repo_path}分支{branch}与上游{remote}/{branch}分支不一致")
     elif branch_type == "tag":
         utils.execute_cmd(["git", "fetch", "--tag"], level="debug")
         utils.execute_cmd(["git", "checkout", branch], level="debug")
